# Changelog

All notable changes to **aperion-flow** will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.1.0] - 2026-02-11

### Added

- Initial release extracted from Aperion monolith
- Pipeline and workflow engine with scheduling, recovery, and strategic routing
- Full test suite
- MIT license

[0.1.0]: https://github.com/invictustitan2/aperion-flow/releases/tag/v0.1.0
